==> webkit2gtk_2.42.2.orig.tar.xz: webkitgtk-2.42.2/Tools/TestWebKitAPI/Tests/WebCore/RenderStyleChange.cpp <==
/*
 * Copyright (C) 2023 Igalia, S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include <WebCore/FontCascadeDescription.h>
#include <WebCore/RenderStyle.h>
#include <WebCore/StyleChange.h>

namespace TestWebKitAPI {

using namespace WebCore;
using namespace Style;

TEST(RenderStyleChangeTest, None)
{
    RenderStyle style1 = RenderStyle::create();
    FontCascadeDescription fontDescription1;
    style1.setFontDescription(WTFMove(fontDescription1));
    RenderStyle style2 = RenderStyle::create();
    FontCascadeDescription fontDescription2;
    style1.setFontDescription(WTFMove(fontDescription2));
    Change change = determineChange(style1, style2);
    EXPECT_EQ(change, Change::None);
}

} // namespace TestWebKitAPI

==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Tools/TestWebKitAPI/Tests/WebCore/RenderStyleChange.cpp <==
/*
 * Copyright (C) 2023 Igalia, S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#include <WebCore/FontCascadeDescription.h>
#include <WebCore/RenderStyle.h>
#include <WebCore/StyleChange.h>

namespace TestWebKitAPI {

using namespace WebCore;
using namespace Style;

TEST(RenderStyleChangeTest, None)
{
    RenderStyle style1 = RenderStyle::create();
    FontCascadeDescription fontDescription1;
    style1.setFontDescription(WTFMove(fontDescription1));
    RenderStyle style2 = RenderStyle::create();
    FontCascadeDescription fontDescription2;
    style1.setFontDescription(WTFMove(fontDescription2));
    auto changes = determineChanges(style1, style2);
    EXPECT_EQ(changes, OptionSet<Change> { });
}

} // namespace TestWebKitAPI
